@@ -1,8 +1,13 @@
 import abc
+from ast import comprehension
 import dataclasses
 import logging
 from datetime import timedelta
 from typing import Dict, List, Optional, Union
+try:  # this will work only in python >= 3.8
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
 
 import confluent_kafka  # type: ignore
 
@@ -22,8 +27,8 @@ class Producer:
         self.conf = conf
         self.logger.debug(f"connecting to producer with config {conf._to_confluent_kafka()}")
         self._producer = confluent_kafka.Producer(conf._to_confluent_kafka())
-        # Workaround for https://github.com/edenhill/librdkafka/issues/3263.
-        # Remove once confluent-kafka-python 1.9.0 has been released.
+        # Workaround for https://github.com/edenhill/librdkafka/issues/3871.
+        # FIXME: Remove once fixed upstream, or on removal of oauth_cb.
         self._producer.poll(0)
 
     def write(self,
@@ -99,6 +104,11 @@ class ProducerConfig:
     # between attempts to reconnect to Kafka.
     reconnect_max_time: timedelta = timedelta(seconds=10)
 
+    compression_type: Optional[Union[Literal['gzip'], Literal['snappy'], Literal['lz4'], Literal['zstd']]] = 'zstd'
+
+    # maximum message size, before compression
+    message_max_bytes: Optional[int] = None
+
     def _to_confluent_kafka(self) -> Dict:
         def as_ms(td: timedelta):
             """Convert a timedelta object to a duration in milliseconds"""
@@ -113,7 +123,10 @@ class ProducerConfig:
             "reconnect.backoff.max.ms": as_ms(self.reconnect_max_time),
             "reconnect.backoff.ms": as_ms(self.reconnect_backoff_time),
             "retry.backoff.ms": as_ms(self.produce_backoff_time),
+            "compression.type": self.compression_type or 'none',
         }
+        if self.message_max_bytes is not None:
+            config['message.max.bytes'] = self.message_max_bytes
         if self.error_callback is not None:
             config["error_cb"] = self.error_callback
         if self.auth is not None:
